@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-12-21 19:50:42
+@LastEditTime: 2022-01-04 17:02:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -210,16 +210,18 @@ class GetCouponPrizeHandler(ClientBaseHandler):
     """
     :description: 领取淘宝优惠券
     """
-    @filter_check_params("user_prize_id")
+    @filter_check_params("act_id,tb_user_id,user_prize_id")
     def get_async(self):
         """
         :description: 领取淘宝优惠券（发奖接口）
         :param user_prize_id:用户奖品标识
+        :param tb_user_id:用户标识
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        open_id = self.get_param("open_id")
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
         user_prize_id = int(self.get_param("user_prize_id", 0))
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
@@ -230,9 +232,10 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         access_token = app_info_dict["access_token"]
         if access_token == "":
             return self.response_json_error("error", "未授权请联系客服授权")
+        dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
         prize_roster_model = PrizeRosterModel(context=self)
-        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id)
-        if not prize_roster_dict or prize_roster_dict['open_id'] != open_id:
+        prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
+        if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             return self.response_json_error("error", "奖品不存在")
         tao_coupon_model = TaoCouponModel(context=self)
         tao_coupon_dict = tao_coupon_model.get_dict(where="prize_id=%s", params=[prize_roster_dict["prize_id"]])
@@ -240,18 +243,20 @@ class GetCouponPrizeHandler(ClientBaseHandler):
             return self.response_json_error("error", "奖品不是优惠券,无需领取")
         top_base_model = TopBaseModel(context=self)
         app_key,app_secret = self.get_app_key_secret()
-        invoke_result_data = top_base_model.alibaba_benefit_send(tao_coupon_dict['right_ename'], open_id, access_token, app_key, app_secret, is_log)
+        invoke_result_data = top_base_model.alibaba_benefit_send(tao_coupon_dict['right_ename'], prize_roster_dict["open_id"], access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             return self.response_json_error("error", "领取失败")
         resp = invoke_result_data.data
         if resp["alibaba_benefit_send_response"]:
             if resp["alibaba_benefit_send_response"]["result_success"] == True:
                 prize_roster_model.update_table("prize_status=1", "id=%s", params=[user_prize_id])
+                prize_roster_model.delete_dependency_key(dependency_key)
                 result = {}
                 result["prize_name"] = resp["alibaba_benefit_send_response"]["prize_name"]
                 return self.response_json_success(result)
             if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_INVALID_OR_DELETED":
                 prize_roster_model.update_table("prize_status=10", "id=%s", params=[user_prize_id])
+                prize_roster_model.delete_dependency_key(dependency_key)
                 return self.response_json_error("error", "领取失败：优惠券无效或已删除")
             if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_SINGLE_COUPON_COUNT_EXCEED_LIMIT":
                 return self.response_json_error("error", "领取失败：优惠券超过限额")
@@ -317,12 +322,12 @@ class AssetLogListHandler(ClientBaseHandler):
         asset_object_id = self.get_param("asset_object_id")
         operate_type = int(self.get_param("operate_type", -1))
 
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
         page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field, is_cache=True, operate_type=operate_type)
         ref_params = {}
