@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-12-14 10:31:13
+@LastEditTime: 2021-12-15 11:44:37
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -108,6 +108,23 @@ class FrameBaseHandler(BaseApiHandler):
             param_ret = StringHelper.filter_special_key(param_ret)
         return param_ret
 
+    def get_param_int(self, param_name, default="", strip=True, filter_sql=False, filter_special_key=False):
+        """
+        :description: 二次封装获取参数转整形
+        :param param_name: 参数名
+        :param default: 如果无此参数，则返回默认值
+        :param filter_sql: 是否过滤sql关键字
+        :param filter_special_key: 是否过滤sql特殊字符
+        :return: 转换后的参数值
+        :last_editors: HuangJianYi
+        """
+        param =  self.get_param(param_name, default, strip, filter_sql, filter_special_key)
+        try:
+            param = int(param)
+        except Exception as ex:
+            param = default
+        return param
+
     def _convert_request_params(self):
         """
         :Description: 转换请求参数 post请求：Content-type必须为application/json，前端必须对对象进行序列化转成json字符串，不能直接传对象,否则无法接收参数
