@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2021-12-21 19:51:19
+@LastEditTime: 2021-12-27 20:12:36
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
@@ -151,4 +151,29 @@ class GetAppIDHandler(ClientBaseHandler):
         """
         store_name = self.get_param("store_name")
         app_base_model = AppBaseModel(context=self)
-        return self.response_json_success(app_base_model.get_app_id(store_name))
\ No newline at end of file
+        return self.response_json_success(app_base_model.get_app_id(store_name))
+
+
+class GetShortUrlHandler(ClientBaseHandler):
+    """
+    :description: 获取淘宝短链接
+    """
+    def get_async(self):
+        """
+        :description: 获取淘宝短链接
+        :param url:链接地址
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        access_token = self.get_param("access_token")
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
+        url = self.get_param("url")
+        app_key, app_secret = self.get_app_key_secret()
+        top_base_model = TopBaseModel(context=self)
+        app_key, app_secret = self.get_app_key_secret()
+        invoke_result_data = top_base_model.get_short_url(url, access_token, app_key, app_secret, is_log)
+        if invoke_result_data.success == False:
+            return self.response_json_success("")
+        else:
+            return self.response_json_success(invoke_result_data.data)
