@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-12-27 13:48:27
+@LastEditTime: 2021-12-30 14:11:16
 @LastEditors: HuangJianYi
 @Description: 奖品模块
 """
@@ -152,18 +152,15 @@ class ActPrizeListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
@@ -290,18 +287,15 @@ class ActPrizeExportHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success("")
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         prize_base_model = PrizeBaseModel(context=self)
         act_prize_list_dict = []
