@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-12-16 11:27:09
+@LastEditTime: 2021-12-27 16:35:22
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -143,7 +143,7 @@ class SevenHelper:
         except Exception:
             pip.unwatch()
             return False
-            
+
     @classmethod
     def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names='', exclude_merge_columns_names=''):
         """
@@ -224,6 +224,32 @@ class SevenHelper:
         list_str = str(int_list).strip('[').strip(']')
         return f"{field_name} IN({list_str})"
 
+    @classmethod
+    def get_condition_in(self, field_name, field_str, field_type=1):
+        '''
+        :description: 根据逗号分隔字符串合成条件
+        :param field_name:字段名
+        :param field_str:逗号分隔字符串
+        :param field_type:字段类型（1整形2字符串）
+        :return: 查询字符串
+        :last_editors: HuangJianYi
+        '''
+        if not field_str:
+            return ""
+        str_list = []
+        if field_type == 1:
+            try:
+                str_list = [int(x) for x in field_str.split(",")]
+            except Exception as ex:
+                pass
+            if len(str_list) <= 0:
+                return ""
+            list_str = str(str_list).strip('[').strip(']')
+        else:
+            str_list = field_str.split(",")
+            list_str = ','.join(["'%s'" % str(item) for item in str_list])
+        return f"{field_name} IN({list_str})"
+
     @classmethod
     def is_ip(self, ip_str):
         """
