@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-11-11 09:45:04
+@LastEditTime: 2022-01-05 17:59:45
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -99,7 +99,13 @@ class WeChatHelper:
             'grant_type': grant_type,
         }
         respone = None
+        redis_init = SevenHelper.redis_init()
+        redis_key = f"wechat_access_token:{str(app_id)}"
         try:
+            access_token = redis_init.get(redis_key)
+            if access_token:
+                invoke_result_data.data = access_token
+                return invoke_result_data
             requset_url = 'https://api.weixin.qq.com/cgi-bin/token'
             respone = requests.get(requset_url, params=param)
             respone_data = SevenHelper.json_loads(respone.text)
@@ -109,6 +115,7 @@ class WeChatHelper:
                 invoke_result_data.error_message = respone_data["errmsg"]
                 return invoke_result_data
             invoke_result_data.data = str(respone_data["access_token"])
+            redis_init.set(redis_key, invoke_result_data.data, ex=3600)
             return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【get_access_token】" + traceback.format_exc())
@@ -117,6 +124,51 @@ class WeChatHelper:
             invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
+    @classmethod
+    def send_template_message(self, open_id, template_id, page, request_data, miniprogram_state="formal", lang="zh_CN", app_id="", app_secret=""):
+        """
+        :description:发送订阅消息（https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/subscribe-message/subscribeMessage.send.html）
+        :param open_id:接收者（用户）的 openid
+        :param template_id:所需下发的订阅模板id
+        :param page:点击模板卡片后的跳转页面，仅限本小程序内的页面。支持带参数,（示例index?foo=bar）。该字段不填则模板无跳转
+        :param request_data:模板内容，格式形如 { “date2”: { “value”: any }, “thing3”: { “value”: any } }
+        :param miniprogram_state:跳转小程序类型：developer为开发版；trial为体验版；formal为正式版；默认为正式版
+        :param lang:进入小程序查看”的语言类型，支持zh_CN(简体中文)、en_US(英文)、zh_HK(繁体中文)、zh_TW(繁体中文)，默认为zh_CN
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        invoke_result_data = self.get_access_token(app_id,app_secret)
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        try:
+            requset_url = 'https://api.weixin.qq.com/cgi-bin/message/subscribe/send'
+            param = {
+                "touser": open_id,
+                "page": page,
+                "lang": lang,
+                "data": request_data,
+                "templateId": template_id,
+                "miniprogramState": miniprogram_state
+                }
+            respone = requests.post(url=requset_url,params={'access_token': invoke_result_data.data},data=json.dumps(param, ensure_ascii=False).encode('utf-8'))
+            respone_data = SevenHelper.json_loads(respone.text)
+            if respone_data.__contains__("errcode") and respone_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = respone_data["errcode"]
+                invoke_result_data.error_message = respone_data["errmsg"]
+                return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【send_template_message】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+        return invoke_result_data
+
     @classmethod
     def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv, app_id="", app_secret=""):
         """
