@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-11-30 17:10:08
+@LastEditTime: 2021-12-21 15:23:50
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -103,7 +103,7 @@ class AppBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "基础信息不存在"
             return invoke_result_data
-        
+
         app_info_dict = None
         if app_id:
             app_info_dict = self.get_app_info_dict(app_id)
@@ -123,7 +123,7 @@ class AppBaseModel():
         helper_info["is_remind_phone"] = base_info_dict["is_remind_phone"]
         helper_info["phone"] = ""
 
-         # 过期时间
+        # 过期时间
         renew_info = {}
         renew_info["surplus_day"] = 0
         dead_date = ""
@@ -170,15 +170,15 @@ class AppBaseModel():
         data["base_info"] = base_info
         invoke_result_data.data =data
         return invoke_result_data
-   
+
     def get_app_info_result(self, user_nick, open_id, access_token, app_key, app_secret):
         """
         :description: 获取小程序信息
         :param user_nick:用户昵称
         :param open_id:open_id
-        :param access_token:access_token
-        :param app_secret: app_secret
         :param access_token: access_token
+        :param app_key:app_key
+        :param app_secret: app_secret
         :return app_info
         :last_editors: HuangJianYi
         """
@@ -194,7 +194,7 @@ class AppBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起，请先授权登录"
             return invoke_result_data
-            
+
         app_info_model = AppInfoModel(context=self.context)
         app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
         top_base_model = TopBaseModel(context=self.context)
@@ -205,12 +205,14 @@ class AppBaseModel():
         now_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(TimeHelper.get_now_format_time('%Y-%m-%d 00:00:00'), '%Y-%m-%d %H:%M:%S'))
         login_log = TaoLoginLogModel(context=self.context).get_entity("open_id=%s", order_by="id desc", params=open_id)
         if app_info:
-            app_info.access_token = access_token
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
+            invoke_result_data = top_base_model.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+            if invoke_result_data.success == True:
+                app_info.access_token = access_token
             app_info_model.update_entity(app_info,"expiration_date,access_token")
             app_info_model.delete_dependency_key(f"app_info:appid_{app_info.app_id}")
-            
+
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
             if app_info.dead_date != "expire":
@@ -223,7 +225,7 @@ class AppBaseModel():
             app_info = AppInfo()
             app_info.access_token = access_token
             base_info = BaseInfoModel(context=self.context).get_dict(field="client_ver")
-            
+
             app_info.template_ver = base_info["client_ver"]
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
@@ -233,4 +235,3 @@ class AppBaseModel():
             app_info.last_login_date = login_log.create_date if login_log else ""
             invoke_result_data.data = app_info
             return invoke_result_data
-            
\ No newline at end of file
