@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-12-23 13:42:18
+@LastEditTime: 2021-12-27 20:07:13
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1318,3 +1318,48 @@ class TopBaseModel():
             elif self.logging_link_error:
                 self.logging_link_error(traceback.format_exc())
             return "expire"
+
+    def get_short_url(self, url, access_token, app_key, app_secret, is_log=False):
+        """
+        :description: 获取短链接
+        :param url：链接地址
+        :param access_token：access_token
+        :param app_key:app_key
+        :param app_secret:app_secret
+        :param is_log：是否记录返回信息
+        :return 短链接地址
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        try:
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.MiniappShorturlCreateRequest()
+            req.article_code = config.get_value("article_code")
+            req.miniapp_url = url
+            resp = req.getResponse(access_token)
+            if is_log:
+                if self.context:
+                    self.context.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取短链接】")
+                elif self.logging_link_info:
+                    self.logging_link_info(str(resp) + "【access_token】：" + access_token + "【获取短链接】")
+            if "miniapp_shorturl_create_response" not in  resp:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "result" not in resp["miniapp_shorturl_create_response"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "model" not in resp["miniapp_shorturl_create_response"]["result"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            if "short_url" not in resp["miniapp_shorturl_create_response"]["result"]["model"]:
+                invoke_result_data.success = False
+                return invoke_result_data
+            invoke_result_data.data = resp["miniapp_shorturl_create_response"]["result"]["model"]["short_url"]
+            return invoke_result_data
+        except Exception as ex:
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
+            invoke_result_data.success = False
+            return invoke_result_data
